@@ -2,8 +2,12 @@
  * Amiga 8SVX format handler: W V Neisius, February 1992
  */
 
+#include "st_i.h"
+
 #include <math.h>
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
+#endif
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -12,36 +16,33 @@
 #include <unistd.h>	/* For SEEK_* defines if not found in stdio */
 #endif
 
-#include "st.h"
-
 /* Private data used by writer */
 typedef struct svxpriv {
-	ULONG nsamples;
+	uint32_t nsamples;
 	FILE *ch[4];
 }*svx_t;
 
-static void svxwriteheader(ft_t, LONG);
+static void svxwriteheader(ft_t, st_ssize_t);
 
 /*======================================================================*/
 /*                         8SVXSTARTREAD                                */
 /*======================================================================*/
 
-int st_svxstartread(ft)
-ft_t ft;
+int st_svxstartread(ft_t ft)
 {
 	svx_t p = (svx_t ) ft->priv;
 
 	char buf[12];
 	char *chunk_buf;
  
-	ULONG totalsize;
-	ULONG chunksize;
+	uint32_t totalsize;
+	uint32_t chunksize;
 
-	ULONG channels;
+	uint32_t channels;
 	unsigned short rate;
 	int i;
 
-	ULONG chan1_pos;
+	long chan1_pos;
 
 	if (! ft->seekable)
 	{
@@ -188,7 +189,7 @@ ft_t ft;
 	chan1_pos = ftell(p->ch[0]);
 
 	for (i = 1; i < channels; i++) {
-		if ((p->ch[i] = fopen(ft->filename, READBINARY)) == NULL)
+		if ((p->ch[i] = fopen(ft->filename, "rb")) == NULL)
 		{
 			st_fail_errno(ft,errno,"Can't open channel file '%s'",
 				ft->filename);
@@ -213,9 +214,7 @@ ft_t ft;
 /*======================================================================*/
 /*                         8SVXREAD                                     */
 /*======================================================================*/
-LONG st_svxread(ft, buf, nsamp) 
-ft_t ft;
-LONG *buf, nsamp;
+st_ssize_t st_svxread(ft_t ft, st_sample_t *buf, st_ssize_t nsamp) 
 {
 	unsigned char datum;
 	int done = 0;
@@ -230,7 +229,7 @@ LONG *buf, nsamp;
 			if (feof(p->ch[i]))
 				return done;
 			/* scale signed up to long's range */
-			*buf++ = LEFT(datum, 24);
+			*buf++ = ST_SIGNED_BYTE_TO_SAMPLE(datum);
 		}
 		done += ft->info.channels;
 	}
@@ -240,8 +239,7 @@ LONG *buf, nsamp;
 /*======================================================================*/
 /*                         8SVXSTOPREAD                                 */
 /*======================================================================*/
-int st_svxstopread(ft)
-ft_t ft;
+int st_svxstopread(ft_t ft)
 {
 	int i;
 
@@ -257,8 +255,7 @@ ft_t ft;
 /*======================================================================*/
 /*                         8SVXSTARTWRITE                               */
 /*======================================================================*/
-int st_svxstartwrite(ft)
-ft_t ft;
+int st_svxstartwrite(ft_t ft)
 {
 	svx_t p = (svx_t ) ft->priv;
 	int i;
@@ -294,9 +291,7 @@ ft_t ft;
 /*                         8SVXWRITE                                    */
 /*======================================================================*/
 
-LONG st_svxwrite(ft, buf, len)
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_svxwrite(ft_t ft, st_sample_t *buf, st_ssize_t len)
 {
 	svx_t p = (svx_t ) ft->priv;
 
@@ -308,7 +303,7 @@ LONG *buf, len;
 
 	while(done < len) {
 		for (i = 0; i < ft->info.channels; i++) {
-			datum = RIGHT(*buf++, 24);
+			datum = ST_SAMPLE_TO_SIGNED_BYTE(*buf++);
 			/* FIXME: Needs to pass ft struct and not FILE */
 			putc(datum, p->ch[i]);
 		}
@@ -321,8 +316,7 @@ LONG *buf, len;
 /*                         8SVXSTOPWRITE                                */
 /*======================================================================*/
 
-int st_svxstopwrite(ft)
-ft_t ft;
+int st_svxstopwrite(ft_t ft)
 {
 	svx_t p = (svx_t ) ft->priv;
 
@@ -363,11 +357,9 @@ ft_t ft;
 /*                         8SVXWRITEHEADER                              */
 /*======================================================================*/
 #define SVXHEADERSIZE 100
-static void svxwriteheader(ft,nsamples)
-ft_t ft;
-LONG nsamples;
+static void svxwriteheader(ft_t ft, st_ssize_t nsamples)
 {
-	LONG formsize =  nsamples + SVXHEADERSIZE - 8;
+	int32_t formsize =  nsamples + SVXHEADERSIZE - 8;
 
 	/* FORM size must be even */
 	if(formsize % 2 != 0) formsize++;
@@ -377,23 +369,23 @@ LONG nsamples;
 	st_writes(ft, "8SVX"); /* File type */
 
 	st_writes(ft, "VHDR");
-	st_writedw(ft, (LONG) 20); /* number of bytes to follow */
+	st_writedw(ft, 20); /* number of bytes to follow */
 	st_writedw(ft, nsamples);  /* samples, 1-shot */
-	st_writedw(ft, (LONG) 0);  /* samples, repeat */
-	st_writedw(ft, (LONG) 0);  /* samples per repeat cycle */
+	st_writedw(ft, 0);  /* samples, repeat */
+	st_writedw(ft, 0);  /* samples per repeat cycle */
 	st_writew(ft, (int) ft->info.rate); /* samples per second */
 	st_writeb(ft,1); /* number of octabes */
 	st_writeb(ft,0); /* data compression (none) */
 	st_writew(ft,1); st_writew(ft,0); /* volume */
 
 	st_writes(ft, "ANNO");
-	st_writedw(ft, (LONG) 32); /* length of block */
+	st_writedw(ft, 32); /* length of block */
 	st_writes(ft, "File created by Sound Exchange  ");
 
 	st_writes(ft, "CHAN");
-	st_writedw(ft, (LONG) 4);
-	st_writedw(ft, (ft->info.channels == 2) ? (LONG) 6 :
-		   (ft->info.channels == 4) ? (LONG) 15 : (LONG) 2);
+	st_writedw(ft, 4);
+	st_writedw(ft, (ft->info.channels == 2) ? 6 :
+		   (ft->info.channels == 4) ? 15 : 2);
 
 	st_writes(ft, "BODY");
 	st_writedw(ft, nsamples); /* samples in file */
