@@ -47,13 +47,10 @@
  */
 
 #include <stdlib.h> /* Harmless, and prototypes atof() etc. --dgc */
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
 #include <math.h>
-#include "st.h"
+#include "st_i.h"
 
-#define DELAY_BUFSIZ ( 50L * MAXRATE )
+#define DELAY_BUFSIZ ( 50L * ST_MAXRATE )
 #define MAX_ECHOS 7	/* 24 bit x ( 1 + MAX_ECHOS ) = */
 			/* 24 bit x 8 = 32 bit !!!	*/
 
@@ -64,33 +61,15 @@ typedef struct echosstuff {
 	double	*delay_buf;
 	float	in_gain, out_gain;
 	float	delay[MAX_ECHOS], decay[MAX_ECHOS];
-	long	samples[MAX_ECHOS], pointer[MAX_ECHOS], sumsamples;
+	st_ssize_t samples[MAX_ECHOS], pointer[MAX_ECHOS], sumsamples;
 } *echos_t;
 
 /* Private data for SKEL file */
 
-
-/* If we are not carefull with the output volume */
-LONG echos_clip24(l)
-LONG l;
-{
-	if (l >= ((LONG)1 << 24))
-		return ((LONG)1 << 24) - 1;
-	else if (l <= -((LONG)1 << 24))
-		return -((LONG)1 << 24) + 1;
-	else
-		return l;
-}
-
-
-
 /*
  * Process options
  */
-void echos_getopts(effp, n, argv) 
-eff_t effp;
-int n;
-char **argv;
+int st_echos_getopts(eff_t effp, int n, char **argv) 
 {
 	echos_t echos = (echos_t) effp->priv;
 	int i;
@@ -98,7 +77,10 @@ char **argv;
 	echos->num_delays = 0;
 
 	if ((n < 4) || (n % 2))
-	    fail("Usage: echos gain-in gain-out delay decay [ delay decay ... ]");
+	{
+	    st_fail("Usage: echos gain-in gain-out delay decay [ delay decay ... ]");
+	    return (ST_EOF);
+	}
 
 	i = 0;
 	sscanf(argv[i++], "%f", &echos->in_gain);
@@ -109,17 +91,20 @@ char **argv;
 		sscanf(argv[i++], "%f", &echos->decay[echos->num_delays]);
 		echos->num_delays++;
 		if ( echos->num_delays > MAX_ECHOS )
-			fail("echos: to many delays, use less than %i delays",
+		{
+			st_fail("echos: to many delays, use less than %i delays",
 				MAX_ECHOS);
+			return (ST_EOF);
+		}
 	}
 	echos->sumsamples = 0;
+	return (ST_SUCCESS);
 }
 
 /*
  * Prepare for processing.
  */
-void echos_start(effp)
-eff_t effp;
+int st_echos_start(eff_t effp)
 {
 	echos_t echos = (echos_t) effp->priv;
 	int i;
@@ -127,55 +112,77 @@ eff_t effp;
 	long j;
 
 	if ( echos->in_gain < 0.0 )
-		fail("echos: gain-in must be positive!\n");
+	{
+		st_fail("echos: gain-in must be positive!\n");
+		return (ST_EOF);
+	}
 	if ( echos->in_gain > 1.0 )
-		fail("echos: gain-in must be less than 1.0!\n");
+	{
+		st_fail("echos: gain-in must be less than 1.0!\n");
+		return (ST_EOF);
+	}
 	if ( echos->out_gain < 0.0 )
-		fail("echos: gain-in must be positive!\n");
+	{
+		st_fail("echos: gain-in must be positive!\n");
+		return (ST_EOF);
+	}
 	for ( i = 0; i < echos->num_delays; i++ ) {
 		echos->samples[i] = echos->delay[i] * effp->ininfo.rate / 1000.0;
 		if ( echos->samples[i] < 1 )
-		    fail("echos: delay must be positive!\n");
+		{
+		    st_fail("echos: delay must be positive!\n");
+		    return (ST_EOF);
+		}
 		if ( echos->samples[i] > DELAY_BUFSIZ )
-			fail("echos: delay must be less than %g seconds!\n",
+		{
+			st_fail("echos: delay must be less than %g seconds!\n",
 				DELAY_BUFSIZ / (float) effp->ininfo.rate );
+			return (ST_EOF);
+		}
 		if ( echos->decay[i] < 0.0 )
-		    fail("echos: decay must be positive!\n" );
+		{
+		    st_fail("echos: decay must be positive!\n" );
+		    return (ST_EOF);
+		}
 		if ( echos->decay[i] > 1.0 )
-		    fail("echos: decay must be less than 1.0!\n" );
+		{
+		    st_fail("echos: decay must be less than 1.0!\n" );
+		    return (ST_EOF);
+		}
 		echos->counter[i] = 0;
 		echos->pointer[i] = echos->sumsamples;
 		echos->sumsamples += echos->samples[i];
 	}
 	if (! (echos->delay_buf = (double *) malloc(sizeof (double) * echos->sumsamples)))
-		fail("echos: Cannot malloc %d bytes!\n", 
-			sizeof(long) * echos->sumsamples);
-	for ( j = 0; j < echos->samples[i]; ++j )
+	{
+		st_fail("echos: Cannot malloc %d bytes!\n", 
+			sizeof(double) * echos->sumsamples);
+		return(ST_EOF);
+	}
+	for ( j = 0; j < echos->sumsamples; ++j )
 		echos->delay_buf[j] = 0.0;
 	/* Be nice and check the hint with warning, if... */
 	sum_in_volume = 1.0;
 	for ( i = 0; i < echos->num_delays; i++ ) 
 		sum_in_volume += echos->decay[i];
 	if ( sum_in_volume * echos->in_gain > 1.0 / echos->out_gain )
-		warn("echos: warning >>> gain-out can cause saturation of output <<<");
+		st_warn("echos: warning >>> gain-out can cause saturation of output <<<");
+	return (ST_SUCCESS);
 }
 
 /*
  * Processed signed long samples from ibuf to obuf.
  * Return number of samples processed.
  */
-
-void echos_flow(effp, ibuf, obuf, isamp, osamp)
-eff_t effp;
-LONG *ibuf, *obuf;
-int *isamp, *osamp;
+int st_echos_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf, 
+                st_size_t *isamp, st_size_t *osamp)
 {
 	echos_t echos = (echos_t) effp->priv;
 	int len, done;
 	int j;
 	
 	double d_in, d_out;
-	LONG out;
+	st_sample_t out;
 
 	len = ((*isamp > *osamp) ? *osamp : *isamp);
 	for(done = 0; done < len; done++) {
@@ -188,7 +195,7 @@ int *isamp, *osamp;
 		}
 		/* Adjust the output volume and size to 24 bit */
 		d_out = d_out * echos->out_gain;
-		out = echos_clip24((LONG) d_out);
+		out = st_clip24((st_sample_t) d_out);
 		*obuf++ = out * 256;
 		/* Mix decay of delays and input */
 		for ( j = 0; j < echos->num_delays; j++ ) {
@@ -204,19 +211,17 @@ int *isamp, *osamp;
 			   ( echos->counter[j] + 1 ) % echos->samples[j];
 	}
 	/* processed all samples */
+	return (ST_SUCCESS);
 }
 
 /*
  * Drain out reverb lines. 
  */
-void echos_drain(effp, obuf, osamp)
-eff_t effp;
-LONG *obuf;
-int *osamp;
+int st_echos_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 {
 	echos_t echos = (echos_t) effp->priv;
 	double d_in, d_out;
-	LONG out;
+	st_sample_t out;
 	int j;
 	long done;
 
@@ -230,7 +235,7 @@ int *osamp;
 		}
 		/* Adjust the output volume and size to 24 bit */
 		d_out = d_out * echos->out_gain;
-		out = echos_clip24((LONG) d_out);
+		out = st_clip24((st_sample_t) d_out);
 		*obuf++ = out * 256;
 		/* Mix decay of delays and input */
 		for ( j = 0; j < echos->num_delays; j++ ) {
@@ -249,17 +254,18 @@ int *osamp;
 	};
 	/* samples played, it remains */
 	*osamp = done;
+	return (ST_SUCCESS);
 }
 
 /*
- * Clean up reverb effect.
+ * Clean up echos effect.
  */
-void echos_stop(effp)
-eff_t effp;
+int st_echos_stop(eff_t effp)
 {
 	echos_t echos = (echos_t) effp->priv;
 
 	free((char *) echos->delay_buf);
 	echos->delay_buf = (double *) -1;   /* guaranteed core dump */
+	return (ST_SUCCESS);
 }
 
