@@ -1,4 +1,3 @@
-#if defined(HAVE_LIBGSM)
 /*
  * Copyright 1991, 1992, 1993 Guido van Rossum And Sundry Contributors.
  * This source code is freely redistributable and may be used for
@@ -27,8 +26,14 @@
  *   Rewritten to support multiple channels
  */
 
-#include "st.h"
-#include "gsm.h"
+#include "st_i.h"
+
+#if defined(ENABLE_GSM)
+
+#include "gsm/gsm.h"
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
 
 #define MAXCHANS 16
 
@@ -47,10 +52,7 @@ struct gsmpriv {
 	gsm		handle[MAXCHANS];
 };
 
-static int
-gsmstart_rw(ft,w) 
-ft_t ft;
-int w; /* w != 0 is write */
+static int gsmstart_rw(ft_t ft, int w) 
 {
 	struct gsmpriv *p = (struct gsmpriv *) ft->priv;
 	int ch;
@@ -85,14 +87,12 @@ int w; /* w != 0 is write */
 	return (ST_SUCCESS);
 }
 
-int st_gsmstartread(ft) 
-ft_t ft;
+int st_gsmstartread(ft_t ft) 
 {
 	return gsmstart_rw(ft,0);
 }
 
-int st_gsmstartwrite(ft)
-ft_t ft;
+int st_gsmstartwrite(ft_t ft)
 {
 	return gsmstart_rw(ft,1);
 }
@@ -104,9 +104,7 @@ ft_t ft;
  * Return number of samples read.
  */
 
-LONG st_gsmread(ft, buf, samp)
-ft_t ft;
-long *buf, samp;
+st_ssize_t st_gsmread(ft_t ft, st_sample_t *buf, st_ssize_t samp)
 {
 	int done = 0;
 	int r, ch, chans;
@@ -118,7 +116,8 @@ long *buf, samp;
 	while (done < samp)
 	{
 		while (p->samplePtr < p->sampleTop && done < samp)
-			buf[done++] = LEFT(*(p->samplePtr)++, 16);
+			buf[done++] = 
+			    ST_SIGNED_WORD_TO_SAMPLE(*(p->samplePtr)++);
 
 		if (done>=samp) break;
 
@@ -148,8 +147,7 @@ long *buf, samp;
 	return done;
 }
 
-static int gsmflush(ft)
-ft_t ft;
+static int gsmflush(ft_t ft)
 {
 	int r, ch, chans;
 	gsm_signal *gbuff;
@@ -184,9 +182,7 @@ ft_t ft;
 	return (ST_SUCCESS);
 }
 
-LONG st_gsmwrite(ft, buf, samp)
-ft_t ft;
-long *buf, samp;
+st_ssize_t st_gsmwrite(ft_t ft, st_sample_t *buf, st_ssize_t samp)
 {
 	int done = 0;
 	struct gsmpriv *p = (struct gsmpriv *) ft->priv;
@@ -194,7 +190,8 @@ long *buf, samp;
 	while (done < samp)
 	{
 		while ((p->samplePtr < p->sampleTop) && (done < samp))
-			*(p->samplePtr)++ = RIGHT(buf[done++], 16);
+			*(p->samplePtr)++ = 
+			    ST_SAMPLE_TO_SIGNED_WORD(buf[done++]);
 
 		if (p->samplePtr == p->sampleTop)
 		{
@@ -208,8 +205,7 @@ long *buf, samp;
 	return done;
 }
 
-int st_gsmstopread(ft)
-ft_t ft;
+int st_gsmstopread(ft_t ft)
 {
 	struct gsmpriv *p = (struct gsmpriv *) ft->priv;
 	int ch;
@@ -222,8 +218,7 @@ ft_t ft;
 	return (ST_SUCCESS);
 }
 
-int st_gsmstopwrite(ft)
-ft_t ft;
+int st_gsmstopwrite(ft_t ft)
 {
     	int rc;
 	struct gsmpriv *p = (struct gsmpriv *) ft->priv;
@@ -237,4 +232,4 @@ ft_t ft;
 
 	return st_gsmstopread(ft); /* destroy handles and free buffers */
 }
-#endif /* HAVE_LIBGSM */
+#endif /* ENABLE_GSM */
