@@ -54,7 +54,8 @@ const char *st_encodings_str[] = {
         "ima_adpcm",
         "gsm",
 	"inversed u-law",
-	"inversed A-law"
+	"inversed A-law",
+	"MPEG audio (layer I, III or III)"
 };
 
 static const char readerr[] = "Premature EOF while reading sample file.";
