@@ -353,8 +353,18 @@ int st_resample_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf,
 	r->Xread = i;                 
 	r->Xp = r->Xoff;
 
-	for(i=0; i < Nout; i++)
-		*obuf++ = r->Y[i] * ISCALE;
+	for(i=0; i < Nout; i++) { 
+		// orig: *obuf++ = r->Y[i] * ISCALE;
+		Float ftemp = r->Y[i] * ISCALE;
+
+		if (ftemp >= ST_SAMPLE_MAX)
+			*obuf = ST_SAMPLE_MAX;
+		else if (ftemp <= ST_SAMPLE_MIN)
+			*obuf = ST_SAMPLE_MIN;
+		else
+			*obuf = ftemp;
+		obuf++;
+        }
 
 	*isamp = Nx;
 	*osamp = Nout;
@@ -383,7 +393,7 @@ int st_resample_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 		st_sample_t Isamp, Osamp;
 		Isamp = isamp_res;
 		Osamp = osamp_res;
-		rc = st_resample_flow(effp, NULL, Obuf, &Isamp, &Osamp);
+		rc = st_resample_flow(effp, NULL, Obuf, (st_size_t *)&Isamp, (st_size_t *)&Osamp);
 		if (rc)
 		    return rc;
 	  /* fprintf(stderr,"DRAIN isamp,osamp  (%d,%d) -> (%d,%d)\n",
