@@ -26,14 +26,15 @@
  *
  */
 
-#include "st.h"
+#include "st_i.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>             /* for malloc() */
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
+#endif
 #include <sys/types.h>          /* for fstat() */
 #include <sys/stat.h>           /* for fstat() */
-
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>             /* for unlink() */
 #endif
@@ -63,10 +64,10 @@ static int clipped = 0;         /* Volume change clipping errors */
 static int writing = 0;         /* are we writing to a file? */
 static int soxpreview = 0;      /* preview mode */
 
-static LONG ibufl[BUFSIZ/2];    /* Left/right interleave buffers */
-static LONG ibufr[BUFSIZ/2];
-static LONG obufl[BUFSIZ/2];
-static LONG obufr[BUFSIZ/2];
+static st_sample_t ibufl[ST_BUFSIZ/2];    /* Left/right interleave buffers */
+static st_sample_t ibufr[ST_BUFSIZ/2];
+static st_sample_t obufl[ST_BUFSIZ/2];
+static st_sample_t obufr[ST_BUFSIZ/2];
 
 /* local forward declarations */
 static void doopts(ft_t, int, char **);
@@ -78,7 +79,7 @@ static void usage(char *) NORET;
 static int filetype(int);
 static void process(void);
 static void statistics(void);
-static LONG volumechange(LONG *buf, LONG ct, double vol);
+static st_sample_t volumechange(st_sample_t *buf, st_ssize_t ct, double vol);
 static void checkeffect(void);
 static int flow_effect_out(void);
 static int flow_effect(int);
@@ -92,10 +93,10 @@ static int drain_effect(int);
 #define REQUIRED_INPUT_FILES 1
 #endif
 
-static ft_t informat[MAX_INPUT_FILES] = { 0 };
+static ft_t informat[MAX_INPUT_FILES];
 static int input_count = 0;
 
-static ft_t outformat = 0;
+static ft_t outformat;
 static int output_count = 0;
 
 /* We parse effects into a temporary effects table and then place into
@@ -132,6 +133,7 @@ char **argv;
         int argc_effect;
         ft_t ft;
         int parsing_output = 0;
+	int i;
 
         myname = argv[0];
 
@@ -260,7 +262,7 @@ char **argv;
             {
                 int i1;
                 fprintf(stderr, "%s: Known effects: ",myname);
-                for (i1 = 1; st_effects[i1].name; i1++)
+                for (i1 = 0; st_effects[i1].name; i1++)
                     fprintf(stderr, "%s ", st_effects[i1].name);
                 fprintf(stderr, "\n\n");
                 st_fail("Effect '%s' is not known!", argv[optind]);
@@ -287,6 +289,14 @@ char **argv;
 
         process();
         statistics();
+
+	for (i = 0; i < input_count; i++)
+	{
+	    if (informat[i])
+		free(informat[i]);
+	}
+	if (outformat)
+	    free(outformat);
         return(0);
 }
 
@@ -299,7 +309,8 @@ static void copy_input(ft_t ft)
         ft->filetype = "auto";
 
     if ( st_gettype(ft) )
-        st_fail("Unknown input file format for '%s'.  Use -t option to override",ft->filename);
+        st_fail("Unknown input file format for '%s':  %s", 
+		ft->filename, ft->st_errstr);
 
     /* Default the input comment to the filename if not set from
      * command line.
@@ -318,7 +329,7 @@ static void open_input(ft_t ft)
      */
     if (! strcmp(ft->filename, "-"))
         ft->fp = stdin;
-    else if ((ft->fp = fopen(ft->filename, READBINARY)) == NULL)
+    else if ((ft->fp = fopen(ft->filename, "rb")) == NULL)
         st_fail("Can't open input file '%s': %s", ft->filename,
                 strerror(errno));
 
@@ -358,7 +369,8 @@ static void copy_output(ft_t ft)
     if (writing && ft->filename)
     {
         if ( st_gettype(ft) )
-            st_fail("Unknown output file format for '%s'.  Use -t option to override",ft->filename);
+            st_fail("Unknown output file format for '%s': %s",
+		    ft->filename, ft->st_errstr);
 
     }
 
@@ -379,14 +391,14 @@ static void open_output(ft_t ft)
 
             /* stdout tends to be line-buffered.  Override this */
             /* to be Full Buffering. */
-            if (setvbuf (ft->fp,NULL,_IOFBF,sizeof(char)*BUFSIZ))
+            if (setvbuf (ft->fp,NULL,_IOFBF,sizeof(char)*ST_BUFSIZ))
             {
                 st_fail("Can't set write buffer");
             }
         }
         else {
 
-            ft->fp = fopen(ft->filename, WRITEBINARY);
+            ft->fp = fopen(ft->filename, "wb");
 
             if (ft->fp == NULL)
                 st_fail("Can't open output file '%s': %s",
@@ -394,7 +406,7 @@ static void open_output(ft_t ft)
 
             /* stdout tends to be line-buffered.  Override this */
             /* to be Full Buffering. */
-            if (setvbuf (ft->fp,NULL,_IOFBF,sizeof(char)*BUFSIZ))
+            if (setvbuf (ft->fp,NULL,_IOFBF,sizeof(char)*ST_BUFSIZ))
             {
                 st_fail("Can't set write buffer");
             }
@@ -409,14 +421,14 @@ static void open_output(ft_t ft)
 }
 
 #ifdef HAVE_GETOPT_H
-static char *getoptstr = "+r:v:t:c:phsuUAaigbwlfdDxV";
+static char *getoptstr = "+r:v:t:c:phsuUAaigbwlfdxV";
 #else
-static char *getoptstr = "r:v:t:c:phsuUAaigbwlfdDxV";
+static char *getoptstr = "r:v:t:c:phsuUAaigbwlfdxV";
 #endif
 
 static void doopts(ft_t ft, int argc, char **argv)
 {
-        int c;
+        int c, i;
         char *str;
 
         while ((c = getopt(argc, argv, getoptstr)) != -1) {
@@ -439,13 +451,8 @@ static void doopts(ft_t ft, int argc, char **argv)
                 case 'r':
                         if (! ft) usage("-r");
                         str = optarg;
-#ifdef __alpha__
                         if ((! sscanf(str, "%u", &ft->info.rate)) ||
                                         (ft->info.rate <= 0))
-#else
-                        if ((! sscanf(str, "%lu", &ft->info.rate)) ||
-                                        (ft->info.rate <= 0))
-#endif
                                 st_fail("-r must be given a positive integer");
                         break;
                 case 'v':
@@ -460,8 +467,16 @@ static void doopts(ft_t ft, int argc, char **argv)
                 case 'c':
                         if (! ft) usage("-c");
                         str = optarg;
-                        if (! sscanf(str, "%d", &ft->info.channels))
-                                st_fail("-c must be given a number");
+                        if (!sscanf(str, "%d", &i))
+                            st_fail("-c must be given a number");
+			/* Since we use -1 as a special internal value,
+			 * we must do some extra logic so user doesn't
+			 * get confused when we translate -1 to mean
+			 * something valid.
+			 */
+			if (i < 1)
+			    st_fail("-c must be given a positive number");
+                        ft->info.channels = i;
                         break;
                 case 'b':
                         if (! ft) usage("-b");
@@ -475,19 +490,10 @@ static void doopts(ft_t ft, int argc, char **argv)
                         if (! ft) usage("-l");
                         ft->info.size = ST_SIZE_DWORD;
                         break;
-                case 'f':
-                        if (! ft) usage("-f");
-                        ft->info.size = ST_SIZE_FLOAT;
-                        break;
                 case 'd':
                         if (! ft) usage("-d");
-                        ft->info.size = ST_SIZE_DOUBLE;
+                        ft->info.size = ST_SIZE_DDWORD;
                         break;
-                case 'D':
-                        if (! ft) usage("-D");
-                        ft->info.size = ST_SIZE_IEEE;
-                        break;
-
                 case 's':
                         if (! ft) usage("-s");
                         ft->info.encoding = ST_ENCODING_SIGN2;
@@ -499,10 +505,18 @@ static void doopts(ft_t ft, int argc, char **argv)
                 case 'U':
                         if (! ft) usage("-U");
                         ft->info.encoding = ST_ENCODING_ULAW;
+                        if (ft->info.size == -1)
+                            ft->info.size = ST_SIZE_BYTE;
                         break;
                 case 'A':
                         if (! ft) usage("-A");
                         ft->info.encoding = ST_ENCODING_ALAW;
+                        if (ft->info.size == -1)
+                            ft->info.size = ST_SIZE_BYTE;
+                        break;
+                case 'f':
+                        if (! ft) usage("-f");
+                        ft->info.encoding = ST_ENCODING_FLOAT;
                         break;
                 case 'a':
                         if (! ft) usage("-a");
@@ -554,8 +568,8 @@ static void process(void) {
     int e, f, flowstatus;
 #ifdef SOXMIX
     int s;
-    ULONG ilen[MAX_INPUT_FILES];
-    LONG *ibuf[MAX_INPUT_FILES];
+    st_ssize_t ilen[MAX_INPUT_FILES];
+    st_sample_t *ibuf[MAX_INPUT_FILES];
 #endif
 
     for (f = 0; f < input_count; f++)
@@ -575,12 +589,12 @@ static void process(void) {
             informat[f]->info.channels = 1;
 
         if ( st_checkformat(informat[f]) )
-            st_fail("bad input format for file %s",informat[f]->filename);
+            st_fail("bad input format for file %s: %s",informat[f]->filename,informat[f]->st_errstr);
 
         st_report("Input file %s: using sample rate %lu\n\tsize %s, encoding %s, %d %s",
                   informat[f]->filename, informat[f]->info.rate,
-                  st_sizes_str[informat[f]->info.size],
-                  st_encodings_str[informat[f]->info.encoding],
+                  st_sizes_str[(unsigned char)informat[f]->info.size],
+                  st_encodings_str[(unsigned char)informat[f]->info.encoding],
                   informat[f]->info.channels,
                   (informat[f]->info.channels > 1) ? "channels" : "channel");
 
@@ -614,12 +628,12 @@ static void process(void) {
         }
 
         if (st_checkformat(outformat))
-                st_fail("bad output format");
+                st_fail("bad output format: %s",outformat->st_errstr);
 
         st_report("Output file %s: using sample rate %lu\n\tsize %s, encoding %s, %d %s",
                outformat->filename, outformat->info.rate,
-               st_sizes_str[outformat->info.size],
-               st_encodings_str[outformat->info.encoding],
+               st_sizes_str[(unsigned char)outformat->info.size],
+               st_encodings_str[(unsigned char)outformat->info.encoding],
                outformat->info.channels,
                (outformat->info.channels > 1) ? "channels" : "channel");
 
@@ -640,14 +654,16 @@ static void process(void) {
     /* Reserve an output buffer for all effects */
     for(e = 0; e < neffects; e++)
     {
-        efftab[e].obuf = (LONG *) malloc(BUFSIZ * sizeof(LONG));
+        efftab[e].obuf = (st_sample_t *) malloc(ST_BUFSIZ * 
+		                                sizeof(st_sample_t));
         if (efftab[e].obuf == NULL)
         {
             st_fail("could not allocate memory");
         }
         if (efftabR[e].name)
         {
-            efftabR[e].obuf = (LONG *) malloc(BUFSIZ * sizeof(LONG));
+            efftabR[e].obuf = (st_sample_t *) malloc(ST_BUFSIZ * 
+		                                     sizeof(st_sample_t));
             if (efftabR[e].obuf == NULL)
             {
                 st_fail("could not allocate memory");
@@ -658,7 +674,7 @@ static void process(void) {
 #ifdef SOXMIX
     for (f = 0; f < MAX_INPUT_FILES; f++)
     {
-        ibuf[f] = (LONG *)malloc(BUFSIZ * sizeof(LONG));
+        ibuf[f] = (st_sample_t *)malloc(ST_BUFSIZ * sizeof(st_sample_t));
         if (!ibuf[f])
         {
             st_fail("could not allocate memory");
@@ -679,28 +695,15 @@ static void process(void) {
 
 #ifndef SOXMIX
         efftab[0].olen = (*informat[0]->h->read)(informat[0],
-                                              efftab[0].obuf, (LONG) BUFSIZ);
-
-        if (informat[0]->st_errno)
-        {
-            st_warn("Error reading from %s: %s", informat[0]->filename,
-                    informat[0]->st_errstr);
-            break;
-        }
+                                                 efftab[0].obuf, 
+						 (st_ssize_t)ST_BUFSIZ);
 #else
         for (f = 0; f < input_count; f++)
         {
             ilen[f] = (*informat[f]->h->read)(informat[f],
-                                              ibuf[f], (LONG)BUFSIZ);
-            if (informat[f]->st_errno)
-            {
-                st_warn("Error reading from %s: %s", informat[f]->filename,
-                        informat[0]->st_errstr);
-                break;
-            }
+                                              ibuf[f], 
+					      (st_ssize_t)ST_BUFSIZ);
         }
-        if (f < input_count && informat[f]->st_errno)
-            break;
 
         efftab[0].olen = 0;
         for (f = 0; f < input_count; f++)
@@ -754,6 +757,15 @@ static void process(void) {
 
     } while (1); /* break; efftab[0].olen == 0 */
 
+#ifdef SOXMIX
+    /* Free input buffers now that they are not used */
+    for (f = 0; f < MAX_INPUT_FILES; f++)
+    {
+        free(ibuf[f]);
+    }
+#endif
+
+
     /* Drain the effects out first to last,
      * pushing residue through subsequent effects */
     /* oh, what a tangled web we weave */
@@ -766,13 +778,20 @@ static void process(void) {
 
             if (writing&&efftab[neffects-1].olen > 0)
                 (* outformat->h->write)(outformat, efftab[neffects-1].obuf,
-                                       (LONG) efftab[neffects-1].olen);
+                                       (st_ssize_t) efftab[neffects-1].olen);
 
-            if (efftab[f].olen != BUFSIZ)
+            if (efftab[f].olen != ST_BUFSIZ)
                 break;
         }
     }
-
+    
+    /* Free output buffers now that they won't be used */
+    for(e = 0; e < neffects; e++)
+    {
+        free(efftab[e].obuf);
+        if (efftabR[e].obuf)
+	    free(efftabR[e].obuf);
+    }
 
     /* Very Important:
      * Effect stop is called BEFORE files close.
@@ -825,8 +844,8 @@ static int flow_effect_out(void)
       if (writing&&(efftab[neffects-1].olen>efftab[neffects-1].odone))
       {
           (* outformat->h->write)(outformat,
-                                     efftab[neffects-1].obuf,
-                                     (LONG) efftab[neffects-1].olen);
+                                  efftab[neffects-1].obuf,
+                                  (st_ssize_t)efftab[neffects-1].olen);
           efftab[neffects-1].odone = efftab[neffects-1].olen;
       }
 
@@ -858,8 +877,8 @@ static int flow_effect_out(void)
 static int flow_effect(e)
 int e;
 {
-    LONG i, done, idone, odone, idonel, odonel, idoner, odoner;
-    LONG *ibuf, *obuf;
+    st_ssize_t i, done, idone, odone, idonel, odonel, idoner, odoner;
+    st_sample_t *ibuf, *obuf;
     int effstatus;
 
     /* I have no input data ? */
@@ -871,10 +890,10 @@ int e;
          * run effect over entire buffer.
          */
         idone = efftab[e-1].olen - efftab[e-1].odone;
-        odone = BUFSIZ;
+        odone = ST_BUFSIZ;
         effstatus = (* efftab[e].h->flow)(&efftab[e],
-                              &efftab[e-1].obuf[efftab[e-1].odone],
-                              efftab[e].obuf, &idone, &odone);
+                                          &efftab[e-1].obuf[efftab[e-1].odone],
+                                          efftab[e].obuf, &idone, &odone);
         efftab[e-1].odone += idone;
         efftab[e].odone = 0;
         efftab[e].olen = odone;
@@ -885,7 +904,7 @@ int e;
          * on each of them.
          */
         idone = efftab[e-1].olen - efftab[e-1].odone;
-        odone = BUFSIZ;
+        odone = ST_BUFSIZ;
         ibuf = &efftab[e-1].obuf[efftab[e-1].odone];
         for(i = 0; i < idone; i += 2) {
             ibufl[i/2] = *ibuf++;
@@ -927,16 +946,16 @@ int e;
 static int drain_effect(e)
 int e;
 {
-    LONG i, olen, olenl, olenr;
-    LONG *obuf;
+    st_ssize_t i, olen, olenl, olenr;
+    st_sample_t *obuf;
 
     if (! efftabR[e].name) {
-        efftab[e].olen = BUFSIZ;
+        efftab[e].olen = ST_BUFSIZ;
         (* efftab[e].h->drain)(&efftab[e],efftab[e].obuf,
                                &efftab[e].olen);
     }
     else {
-        olen = BUFSIZ;
+        olen = ST_BUFSIZ;
 
         /* left */
         olenl = olen/2;
@@ -989,11 +1008,7 @@ checkeffect()
         if (haschan > 1)
             st_fail("Can not specify multiple effects that modify channel #");
         if (hasrate > 1)
-            st_fail("Can not specify multiple effects that change sample rate");
-        if (haschan && !needchan)
-            st_fail("Can not specify channel effects when input and output channel # are equal");
-        if (hasrate && !needrate)
-            st_fail("Can not specify sample rate effects when input and output rate are equal");
+            st_report("Can not specify multiple effects that change sample rate");
 
         /* If not writing output then do not worry about adding
          * channel and rate effects.  This is just to speed things
@@ -1139,14 +1154,12 @@ static void statistics(void) {
                 st_report("Volume change clipped %d samples", clipped);
 }
 
-static LONG volumechange(buf, ct, vol)
-LONG *buf;
-LONG ct;
-double vol;
+static st_sample_t volumechange(st_sample_t *buf, st_ssize_t ct, 
+	                        double vol)
 {
         double y;
-        LONG *p,*top;
-        LONG clips=0;
+        st_sample_t *p,*top;
+        st_ssize_t clips=0;
 
         p = buf;
         top = buf+ct;
@@ -1196,9 +1209,9 @@ char *opt;
                 fprintf(stderr, "Failed: %s\n", opt);
         else {
             fprintf(stderr,"gopts: -e -h -p -v volume -V\n\n");
-            fprintf(stderr,"fopts: -r rate -c channels -s/-u/-U/-A/-a/-i/-g -b/-w/-l/-f/-d/-D -x\n\n");
+            fprintf(stderr,"fopts: -r rate -c channels -s/-u/-U/-A/-a/-i/-g/-f -b/-w/-l/-d -x\n\n");
             fprintf(stderr, "effect: ");
-            for (i = 1; st_effects[i].name != NULL; i++) {
+            for (i = 0; st_effects[i].name != NULL; i++) {
                 fprintf(stderr, "%s ", st_effects[i].name);
             }
             fprintf(stderr, "\n\neffopts: depends on effect\n\n");
@@ -1213,16 +1226,25 @@ char *opt;
 }
 
 
-/* called from util.c:fail */
+/* called from util.c::st_fail() */
 void cleanup(void) {
-        /* Close the input file and outputfile before exiting*/
-        if (informat[0] && informat[0]->fp)
-                fclose(informat[0]->fp);
-        if (outformat && outformat->fp) {
-                fclose(outformat->fp);
-                /* remove the output file because we failed, if it's ours. */
-                /* Don't if its not a regular file. */
-                if (filetype(fileno(outformat->fp)) == S_IFREG)
-                    REMOVE(outformat->filename);
-        }
+    int i;
+
+    /* Close the input file and outputfile before exiting*/
+    for (i = 0; i < input_count; i++)
+    {
+        if (informat[i] && informat[i]->fp)
+                fclose(informat[i]->fp);
+	if (informat[i])
+	    free(informat[i]);
+    }
+    if (outformat && outformat->fp) {
+	fclose(outformat->fp);
+	/* remove the output file because we failed, if it's ours. */
+	/* Don't if its not a regular file. */
+	if (filetype(fileno(outformat->fp)) == S_IFREG)
+	    unlink(outformat->filename);
+    }
+    if (outformat)
+	free(outformat);
 }
