@@ -157,9 +157,12 @@ int st_aiffseek(ft_t ft, st_size_t offset);
 int st_alstartread(ft_t ft);
 int st_alstartwrite(ft_t ft);
 
-#ifdef ALSA_PLAYER
+#ifdef HAVE_ALSA
 int st_alsastartread(ft_t ft);
+st_ssize_t st_alsaread(ft_t ft, st_sample_t *buf, st_ssize_t len);
 int st_alsastartwrite(ft_t ft);
+st_ssize_t st_alsawrite(ft_t ft, st_sample_t *buf, st_ssize_t len);
+int st_alsastopwrite(ft_t ft);
 #endif
 
 int st_austartread(ft_t ft);
@@ -229,6 +232,13 @@ st_ssize_t st_maudwrite(ft_t ft, st_sample_t *buf, st_ssize_t len);
 int st_maudstartwrite(ft_t ft);
 int st_maudstopwrite(ft_t ft);
 
+int st_mp3startread(ft_t ft);
+st_ssize_t st_mp3read(ft_t ft, st_sample_t *buf, st_ssize_t len);
+int st_mp3stopread(ft_t ft);
+st_ssize_t st_mp3write(ft_t ft, st_sample_t *buf, st_ssize_t len);
+int st_mp3startwrite(ft_t ft);
+int st_mp3stopwrite(ft_t ft);
+
 int st_nulstartread(ft_t ft);
 st_ssize_t st_nulread(ft_t ft, st_sample_t *buf, st_ssize_t len);
 int st_nulstopread(ft_t ft);
@@ -236,11 +246,18 @@ int st_nulstartwrite(ft_t ft);
 st_ssize_t st_nulwrite(ft_t ft, st_sample_t *buf, st_ssize_t len);
 int st_nulstopwrite(ft_t ft);
 
-#ifdef OSS_PLAYER
+#ifdef HAVE_OSS
 int st_ossdspstartread(ft_t ft);
 int st_ossdspstartwrite(ft_t ft);
 #endif
 
+int st_prcstartread(ft_t ft);
+st_ssize_t st_prcread(ft_t ft, st_sample_t *buf, st_ssize_t len);
+int st_prcstartwrite(ft_t ft);
+st_ssize_t st_prcwrite(ft_t ft, st_sample_t *buf, st_ssize_t len);
+int st_prcstopwrite(ft_t ft);
+int st_prcseek(ft_t ft, st_size_t offset);
+
 int st_rawstartread(ft_t ft);
 st_ssize_t st_rawread(ft_t ft, st_sample_t *buf, st_ssize_t nsamp);
 int st_rawstopread(ft_t ft);
@@ -278,7 +295,7 @@ int st_spherestartwrite(ft_t ft);
 st_ssize_t st_spherewrite(ft_t ft, st_sample_t *buf, st_ssize_t len);
 int st_spherestopwrite(ft_t ft);
 
-#ifdef SUNAUDIO_PLAYER
+#ifdef HAVE_SUNAUDIO
 int st_sunstartread(ft_t ft);
 int st_sunstartwrite(ft_t ft);
 #endif
