@@ -19,10 +19,9 @@
  * It cannot handle different number of channels.
  * It cannot handle rate change.
  */
-#include "st.h"
+#include "st_i.h"
 
 #include <stdlib.h> /* malloc and free */
-#include <limits.h> /* LONG_MAX */
 #include <string.h> /* memcpy() */
 
 #ifndef MIN
@@ -80,7 +79,7 @@ typedef struct
 
     int size;               /* buffer size */
     int index;              /* next available element */
-    LONG * ibuf;            /* input buffer */
+    st_sample_t *ibuf;      /* input buffer */
     int ishift;             /* input shift */
 
     int oindex;             /* next evailable element */
@@ -106,31 +105,28 @@ static void debug(stretch_t s, char * where)
 
 /* clip amplitudes and count number of clipped values.
  */
-static LONG clip(stretch_t stretch, STRETCH_FLOAT v)
+static st_sample_t clip(stretch_t stretch, STRETCH_FLOAT v)
 {
-    if (v < -LONG_MAX)
+    if (v < -ST_SAMPLE_MAX)
     {
 	stretch->clipped++;
-	return -LONG_MAX;
+	return -ST_SAMPLE_MAX;
     }
-    else if (v > LONG_MAX)
+    else if (v > ST_SAMPLE_MAX)
     {
 	stretch->clipped++;
-	return LONG_MAX;
+	return ST_SAMPLE_MAX;
     }
     else
     {
-	return (LONG) v;
+	return (st_sample_t) v;
     }
 }
 
 /*
  * Process options
  */
-int st_stretch_getopts(effp, n, argv) 
-eff_t effp;
-int n;
-char **argv;
+int st_stretch_getopts(eff_t effp, int n, char **argv) 
 {
     stretch_t stretch = (stretch_t) effp->priv; 
     
@@ -208,8 +204,7 @@ char **argv;
 /*
  * Start processing
  */
-int st_stretch_start(effp)
-eff_t effp;
+int st_stretch_start(eff_t effp)
 {
     stretch_t stretch = (stretch_t) effp->priv;
     register int i;
@@ -235,7 +230,8 @@ eff_t effp;
     stretch->size = (int)(effp->outinfo.rate * ONETHOUSANDS * stretch->window);
     /* start in the middle of an input to avoid initial fading... */
     stretch->index = stretch->size/2;
-    stretch->ibuf  = (LONG *) malloc(stretch->size * sizeof(LONG));
+    stretch->ibuf  = (st_sample_t *) malloc(stretch->size * 
+	                                    sizeof(st_sample_t));
 
     /* the shift ratio deal with the longest of ishift/oshift
        hence ishift<=size and oshift<=size. should be asserted.
@@ -315,10 +311,8 @@ static void combine(stretch_t stretch)
 /*
  * Processes flow.
  */
-int st_stretch_flow(effp, ibuf, obuf, isamp, osamp)
-eff_t effp;
-LONG *ibuf, *obuf;
-LONG *isamp, *osamp;
+int st_stretch_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf, 
+                    st_size_t *isamp, st_size_t *osamp)
 {
     stretch_t stretch = (stretch_t) effp->priv;
     register int iindex, oindex, i;
@@ -334,7 +328,7 @@ LONG *isamp, *osamp;
 				      stretch->size-stretch->index);
 
 	    memcpy(stretch->ibuf+stretch->index, 
-		   ibuf+iindex, tocopy*sizeof(LONG));
+		   ibuf+iindex, tocopy*sizeof(st_sample_t));
 
 	    iindex += tocopy;
 	    stretch->index += tocopy; 
@@ -389,10 +383,7 @@ LONG *isamp, *osamp;
  * Drain buffer at the end
  * maybe not correct ? end might be artificially faded?
  */
-int st_stretch_drain(effp, obuf, osamp)
-eff_t effp;
-LONG *obuf;
-LONG *osamp;
+int st_stretch_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 {
     stretch_t stretch = (stretch_t) effp->priv;
     register int i, oindex;
@@ -425,8 +416,7 @@ LONG *osamp;
  * Do anything required when you stop reading samples.  
  * Don't close input file! 
  */
-int st_stretch_stop(effp)
-eff_t effp;
+int st_stretch_stop(eff_t effp)
 {
     stretch_t stretch = (stretch_t) effp->priv;
 
