@@ -12,10 +12,9 @@
 
 #include <signal.h>
 #include <string.h>
-#include <limits.h>
 #include <math.h>
 #include <ctype.h>
-#include "st.h"
+#include "st_i.h"
 
 #define USSTR ""\
 "Usage:synth [length] type mix [freq[-freq2]] [off] [ph] [p1] [p2] [p3]\n"\
@@ -161,10 +160,10 @@ typedef struct synthstuff {
     double par[MAXCHAN][5];
 
     /* internal stuff */
-    LONG max;
-    ULONG samples_done;
+    st_sample_t max;
+    st_size_t samples_done;
     int rate;
-    ULONG length; /* length in number of samples */
+    st_size_t length; /* length in number of samples */
     double h[MAXCHAN]; /* store values necessary for  creation */
     PinkNoise pinkn[MAXCHAN];
 } *synth_t;
@@ -230,10 +229,7 @@ static void parmcopy(synth_t sy, int s, int d){
  * Don't do initialization now.
  * The 'info' fields are not yet filled in.
  */
-int st_synth_getopts(effp, n, argv) 
-eff_t effp;
-int n;
-char **argv;
+int st_synth_getopts(eff_t effp, int n, char **argv) 
 {
     int argn;
     char *usstr=USSTR;
@@ -246,7 +242,7 @@ char **argv;
     /* set default parameters */
     synth->length = 0; /* use length of input file */
     synth->length_str = 0;
-    synth->max = LONG_MAX;
+    synth->max = ST_SAMPLE_MAX;
     for(c=0;c<MAXCHAN;c++){
 	synth->freq[c] = 440.0;
 	synth->freq2[c] = 440.0;
@@ -426,8 +422,7 @@ char **argv;
  * Prepare processing.
  * Do all initializations.
  */
-int st_synth_start(effp)
-eff_t effp;
+int st_synth_start(eff_t effp)
 {
     int i;
     int c;
@@ -519,8 +514,8 @@ eff_t effp;
 
 
 
-static LONG do_synth(LONG iv, synth_t synth, int c){
-    LONG ov=iv;
+static st_sample_t do_synth(st_sample_t iv, synth_t synth, int c){
+    st_sample_t ov=iv;
     double r=0.0; /* -1 .. +1 */
     double f;
     double om;
@@ -678,7 +673,7 @@ static LONG do_synth(LONG iv, synth_t synth, int c){
 	    ov = iv/2 + r*synth->max/2;
 	    break;
 	case SYNTH_AMOD:
-	    ov = (LONG)(0.5*(r+1.0)*(double)iv);
+	    ov = (st_sample_t)(0.5*(r+1.0)*(double)iv);
 	    break;
 	case SYNTH_FMOD:
 	    ov = iv * r ;
@@ -696,11 +691,8 @@ static LONG do_synth(LONG iv, synth_t synth, int c){
 /*
  * Processed signed long samples from ibuf to obuf.
  */
-
-int st_synth_flow(effp, ibuf, obuf, isamp, osamp)
-eff_t effp;
-LONG *ibuf, *obuf;
-LONG *isamp, *osamp;
+int st_synth_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf, 
+                  st_size_t *isamp, st_size_t *osamp)
 {
     synth_t synth = (synth_t) effp->priv;
     int len; /* number of input samples */
@@ -746,9 +738,7 @@ LONG *isamp, *osamp;
  * Drain out remaining samples if the effect generates any.
  */
 
-int st_synth_drain(effp, obuf, osamp)
-LONG *obuf;
-LONG *osamp;
+int st_synth_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 {
 	*osamp = 0;
 	return (ST_SUCCESS);
@@ -758,8 +748,7 @@ LONG *osamp;
  * Do anything required when you stop reading samples.  
  *	(free allocated memory, etc.)
  */
-int st_synth_stop(effp)
-eff_t effp;
+int st_synth_stop(eff_t effp)
 {
     /* nothing to do */
     return (ST_SUCCESS);
