@@ -133,6 +133,7 @@ int st_vorbisstartread(ft_t ft)
 	else 
 	{
 		comment_size = 0;
+
 		for (i = 0; i < vc->comments; i++)
 			comment_size += vc->comment_lengths[i] + 1;
 
@@ -150,13 +151,16 @@ int st_vorbisstartread(ft_t ft)
 		offset = 0;
 		for (i = 0; i < vc->comments; i++)
 		{
-			strncpy(ft->comment + i, vc->user_comments[i],
+			strncpy(ft->comment + offset, vc->user_comments[i],
 				vc->comment_lengths[i]);
 			offset += vc->comment_lengths[i];
 			ft->comment[offset] = '\n';
 			offset++;
 		}
-		ft->comment[offset] = 0; // End comment
+		/* On last comment, end string by overwriting last \n */
+		if (offset > 0)
+		    offset--;
+		ft->comment[offset] = 0;
 	}
 
 	/* Setup buffer */
@@ -337,9 +341,13 @@ int st_vorbisstartwrite(ft_t ft)
 	fprintf(stdout, "Channels: %d  Rate: %ld\n", ft->info.channels,
 		rate);
 
-	/* Set encoding to average bit rate of 128kbps with no min or max */
-	vorbis_encode_init(&ve->vi, ft->info.channels, ft->info.rate,
-			   -1, 128000, -1);
+	if (rate)
+	{
+	    st_fail_errno(ft, ST_EHDR, "Error setting up Ogg Vorbis encorder - make sure you've specied a sane rate and number of channels");
+	}
+
+	/* Set encoding to average bit rate of 112kbps VBR */
+	vorbis_encode_init_vbr(&ve->vi, ft->info.channels, ft->info.rate, 0.3f);
 
 	vorbis_analysis_init(&ve->vd, &ve->vi);
 	vorbis_block_init(&ve->vd, &ve->vb);
@@ -378,27 +386,31 @@ st_ssize_t st_vorbiswrite(ft_t ft, st_sample_t *buf, st_ssize_t len)
 	{
 		/* Do the main analysis, creating a packet */
 		vorbis_analysis(&ve->vb, &ve->op);
-		
+		vorbis_bitrate_addblock(&ve->vb);
+
 		/* Add packet to bitstream */
-		ogg_stream_packetin(&ve->os,&ve->op);
-		
-		/* If we've gone over a page boundary, we can do actual output,
-		   so do so (for however many pages are available) */
-		
-		while(!eos)
+		while (vorbis_bitrate_flushpacket(&ve->vd, &ve->op)) 
 		{
+		    ogg_stream_packetin(&ve->os,&ve->op);
+		
+    		    /* If we've gone over a page boundary, we can do actual
+		     * output, so do so (for however many pages are available) 
+		     */
+		
+    		    while(!eos)
+    		    {
 			int result = ogg_stream_pageout(&ve->os,&ve->og);
 			if(!result) break;
 			
 			ret = oe_write_page(&ve->og, ft->fp);
 			if(!ret)
-				return (ST_EOF);
+			    return (ST_EOF);
 
 			if(ogg_page_eos(&ve->og))
-				eos = 1;
+			    eos = 1;
+    		    }
 		}
 	}
- 
 
 	return (ST_SUCCESS);	
 }
